#include <iostream.h>
#include <string.h>
#include <stdlib.h>

typedef unsigned char byte;
typedef unsigned int word;
typedef unsigned long card;
typedef enum {false,true} bool;
typedef struct {card lo,hi;} card64;
const card base=1000000000L;

template <class T>
T max(T x, T y)
{return (x > y) ? x : y;
};

class Long
{card *arr;
 word size;
 word count;
 void alloc(word sz)
 {arr=new card[sz];
  size=sz;
 }
 void free(void)
 {delete arr;
  arr=NULL;
  size=0;
 }
 public:
 Long(card a=0)
 {alloc(4);
  *arr=a;
  count=1;
 }
 Long(char *a);
 Long(const Long &a);
 const Long& operator =(const Long& a);
 ~Long(void){free();}
 bool even(void){return (bool)(!(*arr%2));}
 byte mod3(void);
 void operator ++(int);
 void operator --(int);
 Long operator *(const card a) const;
 Long operator -(const Long &a) const;
 bool operator >(const Long &a) const
 {return bool (cmp(this,&a)==1);
 }
 bool operator ==(const Long &a) const
 {return bool (!cmp(this,&a));
 }
 bool operator <(const Long &a) const
 {return bool (cmp(this,&a)==-1);
 }
 bool operator >=(const Long &a) const
 {return bool (cmp(this,&a)>=0);
 }
 bool operator <=(const Long &a) const
 {return bool (cmp(this,&a)<=0);
 }

 Long half(void) const
 {Long r=(*this)*(base/2);
  r.count--;
  memmove(&(r.arr[0]),&(r.arr[1]),r.count*sizeof(card));
  return r;
 }
 Long third(void) const
 {Long r=(*this)*(base/3);
  bool f=(bool)(r.arr[0]>(base/3*2));
  r.count--;
  memmove(&(r.arr[0]),&(r.arr[1]),r.count*sizeof(card));
  if (f) r++;
  return r;
 }
 word len(void) const;

 friend int cmp(const void *a, const void *b);
 friend ostream &operator <<(ostream &o,const Long &a);
};

int cmp(const void *a, const void *b)
{Long *p=(Long *)a, *q=(Long *)b;
 if (p->count>q->count) return 1;
 if (p->count<q->count) return -1;
 for (long i=p->count-1;i>=0;i--)
 {if (p->arr[i]>q->arr[i]) return 1;
  if (p->arr[i]<q->arr[i]) return -1;
 }
 return 0;
}
void mul(const card a,const card b,card64 *r)
{asm {db 0x66
      mov ax,word ptr a //mov eax,a
      db 0x66
      mov bx,word ptr b //mov ebx,b
      db 0x66
      xor dx,dx //xor edx,edx
      db 0x66
      mul bx //mul ebx
      mov bx,0x3B9A //hi(base)
      db 0x66
      shl bx,16 //shl ebx,16
      mov bx,0xCA00 //lo(base)
      db 0x66
      div bx //div ebx
      les di,r
      db 0x66
      mov [es:di],dx //mov [es:di],edx
      db 0x66
      mov [es:di+4],ax //mov [es:di+4],eax
     }
}

Long::Long(char *a)
{long i=0,l=strlen(a);
 char *end;
 alloc(4*(l%9+1));
 while (l>0)
 {char tmp=a[l];
  a[l]=0;
  arr[i++]=strtoul(&a[max(0L,l-9)],&end,10);
  a[l]=tmp;
  l-=9;
 }
 count=i;
}
Long::Long(const Long &a)
{size=a.size;
 count=a.count;
 alloc(size);
 for (word i=0;i<count;i++) arr[i]=a.arr[i];
}
const Long& Long::operator =(const Long& a)
{if (this!=&a)
 {free();
  size=a.size;
  count=a.count;
  alloc(size);
  for (word i=0;i<count;i++) arr[i]=a.arr[i];
 }
 return *this;
}
byte Long::mod3(void)
{word s=0;
 for (word i=0;i<count;i++) s+=arr[i]%3;
 return s%3;
}
void Long::operator ++(int)
{bool c=true;
 for (word i=0;c&&i<count;i++) {arr[i]++;
				c=(bool)(arr[i]>=base);
				if (c) arr[i]=0;
			       }
 if (c) arr[count++]=1;
}
void Long::operator --(int)
{bool c=true;
 for (word i=0;c&&i<count;i++) {if (arr[i]>0L) {arr[i]--;
						c=false;}
				else {arr[i]=base-1;
				      c=true;}
			       }
}
Long Long::operator *(const card a) const
{card64 t;
 card c=0;
 Long r=*this;
 for (word i=0;i<count;i++)
 {mul(arr[i],a,&t);
  r.arr[i]=t.lo+c;
  c=t.hi;
 }
 if (c) r.arr[r.count++]=c;
 return r;
}
Long Long::operator -(const Long &a) const
{Long r=*this;
 card borrow=0;
 for (word i=0;i<count;i++)
 {if (r.arr[i]<a.arr[i]-borrow){r.arr[i]=r.arr[i]+base-a.arr[i]-borrow;
				borrow=1;
			       }
  else {r.arr[i]=r.arr[i]-a.arr[i]-borrow;
	borrow=0;
       }
 }
 while (r.count>1&&!r.arr[count-1])r.count--;
 return r;
}
word Long::len(void) const
{word l=0;
 Long t=*this;
 while (t.count>1||(t.count==1&&t.arr[0]!=1))
 {while (!t.mod3()) {t=t.third();l++;}
  while (t.even()) {t=t.half();l++;}
  if (t.count>1||(t.count==1&&t.arr[0]!=1)) {t++;l++;}
 }
 return l;
}

ostream &operator <<(ostream &o,const Long &a)
{o<<a.arr[a.count-1];
 for (long i=(long)a.count-2;i>=0;i--)
 {o.fill('0');
  o.width(9);
  o<<a.arr[i];
 }
 return o;
}

word direct(char *a, char *b)
{Long p(a),q(b),s(10),tmp;
 word t,r=0;
 byte d;
 if (q-p<=s) {while (p<=q) {t=p.len();
			    if (t>r) {r=t;tmp=p;}
			    p++;
			   }
	      cout<<"Direct: "<<tmp<<endl;
	      return r;
	     }
 if (p.even()) {r=p.len();tmp=p;p++;}
 d=p.mod3();
 if (!d) {if (r<p.len()) {r=p.len();tmp=p;}
	      p++;d++;}
 if (p.even()) {if (r<p.len()) {r=p.len();tmp=p;}
		p++;d++;}
 d%=2;
 while (p<=q) {t=p.len();
	       if (t>r) {r=t;tmp=p;}
	       p++;p++;
	       if (d) {p++;p++;}
	       d^=1;
 }
 cout<<"Direct: "<<tmp<<endl;
 return r;
}

void fast(char *a, char *b,word *r)
{Long p(a),q(b),tmp,tm;
 card k=1,mm,m=0;
 do {Long t(3*(2*k-1)+1);

     if (t>=a) break;

     mm=t.len();
     while (t<=q)
     {tmp=t;
      t=t*2;
      t--;
      mm+=2;
     }
     if (tmp>=p){mm-=2;
		 if (mm<m) {*r=m; tmp=tm;}
		 else *r=mm;
		 cout<<"len="<<mm<<", k="<<k<<", Fast: "<<tmp<<", check "<<tmp.len()<<endl;
//		 return;
		}
     else{
     tmp++;
     if (tmp==p){mm-=3;
		 m=max(m,mm);
		 tm=max(tmp,tm);
		 cout<<"len="<<mm<<", k="<<k<<", Fast: "<<tmp<<", check "<<tmp.len()<<endl;
		 //return;
		}
     }
     k++;
//    } while (1);
  }  while (k<=10000);
/*  *r=max(m,mm);
    tmp=max(tmp,tm);
    cout<<"k="<<k<<", Fast: "<<tmp<<", check "<<tmp.len()<<endl;
*/
}

void main(void)
{char a[32],b[32];
 Long tt(20000);
 word r;
// cout<<"A=";
 cin>>a;
// cout<<"B=";
 cin>>b;
 cout<<"["<<a<<", "<<b<<"]\n";
 Long A(a),B(b);
 if (B-A<=tt)
 {cout<<direct(a,b)<<endl;
//  return;
 }

 fast(a,b,&r);
 cout<<r<<endl;
}